@@ -3,7 +3,7 @@ package Labyrinth::Plugin::Hits;
 use strict;
 use warnings;
 
-my $VERSION = '5.12';
+my $VERSION = '5.13';
 
 =head1 NAME
 
@@ -65,12 +65,20 @@ Records the hit for the current page and photo (if applicable).
 
 =item HitPages
 
+List of hit stats for site pages.
+
 =item HitAlbums
 
+List of hit stats for galley albums.
+
 =item HitPhotos
 
+List of hit stats for galley photos.
+
 =item HitSelects
 
+Compile contents of the drop downs on hit pages.
+
 =back
 
 =cut
@@ -207,18 +215,30 @@ sub HitSelects {
 
 =item AdminUpdates
 
+List the last site page updates, via the 'AdminUpdates' phrasebook query.
+
 =item SetUpdates
 
+Store page and site update from current timestamp. Only called internally.
+
 =item AdminHits
 
+Shorthand method to list all the hit counters for admin use.
+
 =item Reset
 
+Original method to reset hit counters, such that individual counters older than
+a given date, are summed and stored in one counter entry.
+
+This is being deprecated in favour of a new script, which will be incorporated
+here in the future.
+
 =back
 
 =cut
 
 sub AdminUpdates {
-    return  unless AccessUser(ADMIN);
+    return  unless AccessUser(EDITOR);
     my @rs = $dbi->GetQuery('hash','AdminUpdates');
 
     foreach my $rec (@rs) {
@@ -252,7 +272,7 @@ sub SetUpdates {
 }
 
 sub AdminHits {
-    return  unless AccessUser(ADMIN);
+    return  unless AccessUser(EDITOR);
     HitPages();
     HitAlbums();
     HitPhotos();
