@@ -3,7 +3,7 @@ package Labyrinth::Plugin::Users;
 use warnings;
 use strict;
 
-my $VERSION = '5.12';
+my $VERSION = '5.13';
 
 =head1 NAME
 
@@ -77,18 +77,33 @@ my $LEVEL = ADMIN;
 
 =item UserLists
 
+Provide the current user list, taking into account of any search strings and
+filters.
+
 =item Gravatar
 
+Provide the gravatar for a specified user.
+
 =item Item
 
+Provide the content attributed to the specified user.
+
 =item Name
 
+Provide the name of the specified user.
+
 =item Password
 
+Check and store a change of password.
+
 =item Register
 
+Provide the template variable hash for a new user to register.
+
 =item Registered
 
+Set the email address for the newly registered user, to auto log them in.
+
 =back
 
 =cut
@@ -275,34 +290,63 @@ sub Registered {
 
 =item Login
 
+Action the login functionality to the site.
+
 =item Logout
 
+Action the logout functionality to the site.
+
 =item Store
 
 =item Retrieve
 
 =item LoggedIn
 
+Check with the current user is logged in.
+
 =item ImageCheck
 
+Check whether images uploaded for the user profile are still being used. Used
+to allow the images plugin to delete unused images.
+
 =item Admin
 
+List current users.
+
 =item Add
 
+Provide the template variable hash to create a new user.
+
 =item Edit
 
+Edit the given user.
+
 =item Save
 
+Save the given user. For use by the currently logged in user.
+
 =item AdminSave
 
+Save the given user. For use by admin user to update any non-system user.
+
 =item Delete
 
+Delete the specified user.
+
 =item Ban
 
+Ban the specified user.
+
 =item AdminPass
 
+Allow the admin user to create a new password of a given user.
+
+Note passwords are store in an encrypted format, so cannot be viewed.
+
 =item AdminChng
 
+Allow the admin user to change the password of a given user.
+
 =cut
 
 sub Login    { Labyrinth::Session::Login()    }
@@ -437,7 +481,7 @@ sub Save {
 }
 
 sub AdminSave {
-    return  unless AccessUser(ADMIN);
+    return  unless AccessUser($LEVEL);
     return  unless MasterCheck();
 
     my $newuser = $cgiparams{'userid'} ? 0 : 1;
@@ -556,10 +600,16 @@ sub AdminChng {
 
 =item ACL
 
+List the current access control levels for the given user.
+
 =item ACLSave
 
+Save changes to the current access control levels for the given user.
+
 =item ACLDelete
 
+Delete the specified access control level for the given user.
+
 =cut
 
 sub ACL {
